from .samtools import MultiqcModule

__all__ = ["MultiqcModule"]
